caldav/config

Types

Stores the connection settings used by the CalDAV client.

pub type Config {
  Config(
    base_url: String,
    auth: auth.Auth,
    user_agent: String,
    timeout_ms: Int,
  )
}

Constructors

  • Config(
      base_url: String,
      auth: auth.Auth,
      user_agent: String,
      timeout_ms: Int,
    )

Values

pub fn new(base_url: String, auth: auth.Auth) -> Config

Creates a config with the required base URL and authentication settings.

pub fn with_timeout(config: Config, timeout_ms: Int) -> Config

Returns a copy of the config with a custom timeout in milliseconds.

pub fn with_user_agent(
  config: Config,
  user_agent: String,
) -> Config

Returns a copy of the config with a custom user agent.

Search Document